tfprob: Exntension of TensorFlow Probability
=======================


Packages:

- `tf`:   `tensorflow`

- `tfk`:  `tensorflow.keras`

- `tfp`:  `tensorflow_probability`

- `tfb`:  `tensorflow_probability.bijectors`

- `tfd`:  `tensorflow_probability.distributions`


Note: We no longer maintain our own version of probability framework. Please use the version provided by TensorFlow instead.

